@@ -4,7 +4,7 @@
 Gnuplot for python
 """
 
-import sys, os, string, types
+import sys, os, string, types, time
 import collections
 import subprocess
 try:
@@ -203,7 +203,9 @@ class Gnuplot(object):
 
         for c in commands:
             if self.log:
-                print("\033[1;34m[py-gnuplot]\033[0m %s" %(c))
+                #now = time.strftime('%Y%m%d-%H:%M:%S', time.localtime(time.time()))
+                now = time.strftime('%H:%M:%S', time.localtime(time.time()))
+                print("\033[1;34m[py-gnuplot %s]\033[0m %s" %(now, c))
             self.__call__('%s' %(c))
 
     def close(self):
@@ -287,7 +289,7 @@ class Gnuplot(object):
 
         # unset the label if it's in multiplot mode.
         if self.isMultiplot:
-            g.unset('for [i=1:200] label i')
+            self.unset('for [i=1:200] label i')
 
     def plot_data(self, data, *items, **kwargs):
         '''
@@ -351,7 +353,7 @@ class Gnuplot(object):
 
         # unset the label if it's in multiplot mode.
         if self.isMultiplot:
-            g.unset('for [i=1:200] label i')
+            self.unset('for [i=1:200] label i')
 
     def splot(self, *items, **kwargs):
         self.set(**kwargs)
@@ -363,7 +365,7 @@ class Gnuplot(object):
 
         # unset the label if it's in multiplot mode.
         if self.isMultiplot:
-            g.unset('for [i=1:200] label i')
+            self.unset('for [i=1:200] label i')
 
 
     def evaluate(self, cmd):
